``baseplate.lib.metrics``
=========================

.. automodule:: baseplate.lib.metrics

Clients
-------

.. autofunction:: metrics_client_from_config

.. autoclass:: Client()
   :members:
   :inherited-members:

.. autoclass:: Batch()
   :members:
   :inherited-members:

Metrics
-------

.. autoclass:: Counter()
   :members:
   :undoc-members:

.. autoclass:: Timer()
   :members:

.. autoclass:: Gauge()
   :members:
   :undoc-members:

.. autoclass:: Histogram()
   :members:
   :undoc-members:
